@@ -1,18 +1,16 @@
 import logging
-from tempfile import NamedTemporaryFile
 import os
 import pickle
 from pathlib import Path
+from tempfile import NamedTemporaryFile
 from typing import cast
 from typing import Dict
-from typing import Any
 
 from potodo import __version__ as VERSION
 from potodo.po_file import PoFileStats
 
 
 def get_cache_file_content(
-    cache_args: Any,
     path: str = ".potodo/cache.pickle",
 ) -> Dict[Path, PoFileStats]:
     logging.debug("Trying to load cache from %s", path)
@@ -24,7 +22,7 @@ def get_cache_file_content(
         return {}
     else:
         logging.debug("Found cache")
-        if data.get("version") != VERSION or cache_args != data.get("args"):
+        if data.get("version") != VERSION:
             logging.info("Found old cache, ignored it.")
             return {}
         else:
@@ -32,10 +30,10 @@ def get_cache_file_content(
 
 
 def set_cache_content(
-    obj: Dict[Path, PoFileStats], cache_args: Any, path: str = ".potodo/cache.pickle"
+    obj: Dict[Path, PoFileStats], path: str = ".potodo/cache.pickle"
 ) -> None:
     os.makedirs(os.path.dirname(path), exist_ok=True)
-    data = {"version": VERSION, "args": cache_args, "data": obj}
+    data = {"version": VERSION, "data": obj}
     with NamedTemporaryFile(
         mode="wb", delete=False, dir=str(Path(path).parent), prefix=Path(path).name
     ) as tmp:
