@@ -77,7 +77,7 @@ def _get_reservation_list(repo_path: Path) -> Dict[str, Tuple[Any, Any]]:
 
     for issue in issues:
         # Maybe find a better way for not using python 3.8 ?
-        yes = re.search(r"\w*/\w*\.po", issue["title"])
+        yes = re.search(r"\w*/(\w|\.)*\.po", issue["title"])
         if yes:
             creation_date = datetime.strptime(
                 issue["created_at"].split("T")[0], "%Y-%m-%d"
